%global nhgamedir /usr/games/nethack
%global nhdatadir /var/games/nethack

%global fontfamily nethack-bitmap
%global fonts *.pcf
%global _myfontname nethack-bitmap
%global _fontdir %{_datadir}/fonts/nethack-bitmap-fonts

Name:           nethack
Version:        3.6.7
Release:        %mkrel 1
Summary:        A rogue-like single player dungeon exploration game

Group:          Games/Adventure
License:        NGPL
URL:            https://nethack.org
Source0:        https://nethack.org/download/%{version}/%{name}-367-src.tgz
Source1:        %{name}.desktop
Patch0:         %{name}-3.6.2-makefile.patch
Patch1:         %{name}-3.6.2-config.patch
Patch2:         Makefile.top.patch
Patch3:         %{name}-3.6.6-guidebook.patch
Requires:       %{_myfontname}-fonts-core

BuildRequires:  bdftopcf
BuildRequires:  bison
BuildRequires:  desktop-file-utils
BuildRequires:  flex
BuildRequires:  fontpackages-devel
BuildRequires:  gcc
BuildRequires:  mkfontdir
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xt)


%description
NetHack is a single player dungeon exploration game that runs on a
wide variety of computer systems, with a variety of graphical and text
interfaces all using the same game engine.

Unlike many other Dungeons & Dragons-inspired games, the emphasis in
NetHack is on discovering the detail of the dungeon and not simply
killing everything in sight - in fact, killing everything in sight is
a good way to die quickly.

Each game presents a different landscape - the random number generator
provides an essentially unlimited number of variations of the dungeon
and its denizens to be discovered by the player in one of a number of
characters: you can pick your race, your role, and your gender.


%package -n %{_myfontname}-fonts
Summary:        Bitmap fonts for Nethack
Group:          System/Fonts/X11 bitmap
BuildArch:      noarch
Requires:       fontpackages-filesystem

%description -n %{_myfontname}-fonts
Bitmap fonts for Nethack.

%package -n %{_myfontname}-fonts-core
Summary:         X11 core fonts configuration for %{name}
Group:          System/Fonts/X11 bitmap
BuildArch:      noarch
Requires:        %{_myfontname}-fonts
Requires(post):  %{_myfontname}-fonts
Requires(post):  coreutils
Requires(post):  mkfontdir
Requires(preun): coreutils


%description -n %{_myfontname}-fonts-core
X11 core fonts configuration for %{_myfontname}.


%prep
%autosetup -p0 -n NetHack-%{version}

sed -i -e "s:PREFIX=\$(wildcard ~)/nh/install:PREFIX=/usr:" sys/unix/hints/linux
sed -i -e "s:^\(HACKDIR=\).*:\1%{nhgamedir}:" sys/unix/hints/linux
sh sys/unix/setup.sh sys/unix/hints/linux

# Set our paths
sed -i -e "s:^\(HACKDIR=\).*:\1%{nhgamedir}:" sys/unix/nethack.sh
sed -i -e "s:FEDORA_CONFDIR:%{nhgamedir}:" sys/unix/nethack.sh
sed -i -e "s:FEDORA_STATEDIR:%{nhdatadir}:" include/unixconf.h
sed -i -e "s:FEDORA_HACKDIR:%{nhgamedir}:" include/config.h
sed -i -e "s:/usr/games/lib/nethackdir:%{nhgamedir}:" \
        doc/nethack.6 doc/nethack.txt doc/recover.6 doc/recover.txt

# Point the linker in the right direction
sed -i -e "s:-L/usr/X11R6/lib:-L/usr/X11R6/%{_lib}:" \
        src/Makefile util/Makefile

%build
make all

%install
%make_install \
        PREFIX=%{buildroot} \
        HACKDIR=%{buildroot}%{nhgamedir} \
        GAMEDIR=%{buildroot}%{nhgamedir} \
        VARDIR=%{buildroot}%{nhdatadir} \
        SHELLDIR=%{buildroot}%{_bindir} \
        CHOWN=/bin/true \
        CHGRP=/bin/true

install -d -m 0755 %{buildroot}%{_mandir}/man6
make -C doc MANDIR=%{buildroot}%{_mandir}/man6 manpages

install -D -p -m 0644 win/X11/nh_icon.xpm \
        %{buildroot}%{_datadir}/pixmaps/nethack.xpm

desktop-file-install \
        --dir %{buildroot}%{_datadir}/applications \
        %{SOURCE1}

# Install the fonts for the X11 interface
cd win/X11
bdftopcf -o nh10.pcf nh10.bdf
bdftopcf -o ibm.pcf ibm.bdf
%fontinstall

# install -m 0755 -d $RPM_BUILD_ROOT%%{_fontdir}
# install -m 0644 -p *.pcf $RPM_BUILD_ROOT%%{_fontdir}

sed -i -e 's:^!\(NetHack.tile_file.*\):\1:' \
        %{buildroot}%{nhgamedir}/NetHack.ad

%post -n %{_myfontname}-fonts-core
if [ -L /etc/X11/fontpath.d/nethack ] ; then
    rm /etc/X11/fontpath.d/nethack
fi
mkfontdir %{_fontdir}
if [ ! -L /etc/X11/fontpath.d/nethack ] ; then
    ln -s %{_fontdir} /etc/X11/fontpath.d/nethack
fi

%preun -n %{_myfontname}-fonts-core
if [ $1 -eq 0 ] ; then
    rm /etc/X11/fontpath.d/nethack
    rm %{_fontdir}/fonts.dir
fi;


%files
%doc doc/*.txt README dat/license dat/history
%doc dat/opthelp dat/wizhelp
%{_mandir}/man6/*.6*
%{_datadir}/pixmaps/nethack.xpm
%{_datadir}/applications/nethack.desktop
%{_bindir}/nethack
# %%{nhgamedir}
%defattr(0664,root,games)
%config(noreplace) %{nhdatadir}/record
%config(noreplace) %{nhdatadir}/perm
%config(noreplace) %{nhdatadir}/logfile
%config(noreplace) %{nhdatadir}/xlogfile
%attr(0775,root,games) %dir %{nhdatadir}
%attr(0775,root,games) %dir %{nhdatadir}/save
%attr(2755,root,games) %{nhgamedir}/nethack
%config(noreplace) %{nhgamedir}/nhdat
%config(noreplace) %{nhgamedir}/sysconf
%config(noreplace) %{nhgamedir}/NetHack.ad
%config(noreplace) %{nhgamedir}/license
%config(noreplace) %{nhgamedir}/pet_mark.xbm
%config(noreplace) %attr(0555,root,games) %{nhgamedir}/recover
%config(noreplace) %{nhgamedir}/rip.xpm
%config(noreplace) %{nhgamedir}/pilemark.xbm
%config(noreplace) %{nhgamedir}/symbols
%config(noreplace) %{nhgamedir}/x11tiles

# %%_font_pkg -n bitmap *.pcf
%fontfiles

%files -n %{_myfontname}-fonts-core



%changelog
* Sun Mar 19 2023 daviddavid <daviddavid> 3.6.7-1.mga9
+ Revision: 1949676
- new version: 3.6.7

* Sat Mar 18 2023 daviddavid <daviddavid> 3.6.6-8.mga9
+ Revision: 1949657
- make sure '/etc/X11/fontpath.d/nethack' is not installed before upgrade

* Sat Mar 18 2023 daviddavid <daviddavid> 3.6.6-7.mga9
+ Revision: 1949636
- fix dangling links: /etc/X11/fontpath.d/nethack -> /usr/share/fonts/nethack (mga#30609)

* Thu Mar 31 2022 umeabot <umeabot> 3.6.6-6.mga9
+ Revision: 1836435
- Mageia 9 Mass Rebuild

* Sat Mar 12 2022 danf <danf> 3.6.6-5.mga9
+ Revision: 1790504
- Add warn-unused.patch to fix building on gcc 12

* Sat Aug 01 2020 tv <tv> 3.6.6-4.mga8
+ Revision: 1610414
- fix unexpanded-macro Summary
+ shlomif <shlomif>
- fonts macro updates+move to core/release

* Wed Jul 22 2020 shlomif <shlomif> 3.6.6-3.mga8
+ Revision: 1607790
- Fix install deps

* Wed Jul 22 2020 shlomif <shlomif> 3.6.6-2.mga8
+ Revision: 1607782
- Sync patches and .spec from fedora. Experimental.

* Fri Mar 20 2020 daviddavid <daviddavid> 3.6.6-1.mga8
+ Revision: 1558157
- new version: 3.6.6, fixes CVE-2020-5254 (mga#26228)

* Thu Feb 20 2020 umeabot <umeabot> 3.6.5-2.mga8
+ Revision: 1547334
- Mageia 8 Mass Rebuild

* Fri Feb 07 2020 shlomif <shlomif> 3.6.5-1.mga8
+ Revision: 1487880
- New version 3.6.5

* Thu Dec 26 2019 shlomif <shlomif> 3.6.4-1.mga8
+ Revision: 1470155
- New version 3.6.4

* Sun Jun 30 2019 shlomif <shlomif> 3.6.2-1.mga8
+ Revision: 1416212
- New version 3.6.2

* Wed Sep 12 2018 shlomif <shlomif> 3.6.1-1.mga7
+ Revision: 1258685
- New version 3.6.1

* Thu Aug 24 2017 ovitters <ovitters> 3.6.0-1.mga7
+ Revision: 1145251
+ rebuild (emptylog)

* Sat Mar 05 2016 shlomif <shlomif> 3.6.0-1.mga6
+ Revision: 986121
- Correct dep
- Importing nethack-3.6.0 based on the fedora package (thanks)


* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.4.3-33
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.4.3-32
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Wed Jun 18 2014 Luke Macken <lmacken@redhat.com> - 3.4.3-31
- Apply a patch to fix the build with -Werror=format-security (#1037215, #1106286)

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.4.3-30
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.4.3-29
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Feb 12 2013 Jon Ciesla <limburgher@gmail.com> - 3.4.3-28
- Drop desktop vendor tag.

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.4.3-27
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.4.3-26
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.4.3-25
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Jan 11 2010 Luke Macken <lmacken@redhat.com> - 3.4.3-24
- Fix the source URL

* Tue Sep 01 2009 Luke Macken <lmacken@redhat.com> - 3.4.3-23
- Fix the categories for the nethack desktop entry (#485362)

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.4.3-22
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Jul 10 2009 Luke Macken <lmacken@redhat.com> - 3.4.3-21
- Apply a patch from Iain Arnell to update our spec to comply with
  the new font packaging guidelines (#505613)

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.4.3-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 18 2009 Jochen Schmitt <Jochen herr-schmitt de> - 3.4.3-19
- Add missing Requires

* Mon Aug 11 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 3.4.3-18
- fix license tag

* Fri Feb  8 2008 Luke Macken <lmacken@redhat.com> - 3.4.3-17
- Rebuild for gcc 4.3

* Thu Jan 17 2008 Luke Macken <lmacken@redhat.com> 3.4.3-16
- Create a symlink to our fonts in /etc/X11/fontpath.d (Bug #221692)

* Tue Aug 21 2007 Luke Macken <lmacken@redhat.com> 3.4.3-15
- Rebuild

* Mon Jul  9 2007 Luke Macken <lmacken@redhat.com> 3.4.3-14
- Fix nethack.desktop (Bug #247373)

* Sun Jul 08 2007 Florian La Roche <laroche@redhat.com> 3.4.3-13
- require xorg-x11-font-utils (to run mkfontdir) for post script

* Mon Oct 16 2006 Luke Macken <lmacken@redhat.com> 3.4.3-12
- Own /usr/games/nethack-3.4.3

* Sun Sep  3 2006 Luke Macken <lmacken@redhat.com> 3.4.3-11
- Rebuild for FC6

* Mon Apr 10 2006 Luke Macken <lmacken@redhat.com> 3.4.3-10
- Remove $RPM_BUILD_ROOT from %%post (Bug #188008)

* Wed Feb 15 2006 Luke Macken <lmacken@redhat.com> 3.4.3-9
- Add nethack-3.4.3-guidebook.patch to fix issues with generating the Guidebook
  (this patch also removes the need for our groff dep)

* Wed Feb 15 2006 Luke Macken <lmacken@redhat.com> 3.4.3-8
- Add groff to BuildRequires

* Tue Feb 14 2006 Luke Macken <lmacken@redhat.com> 3.4.3-7
- Rebuild for FE5

* Tue Dec 27 2005 Luke Macken <lmacken@redhat.com> 3.4.3-6
- Rebuild

* Wed Nov 23 2005 Luke Macken <lmacken@redhat.com> 3.4.3-5
- Keep the license in the game directory (Bug #173385)
- Don't obsolete falconseye anymore (Bug #173385)

* Fri Nov 11 2005 Luke Macken <lmacken@redhat.com> 3.4.3-4
- Utilize modular xorg

* Thu Sep 08 2005 Luke Macken <lmacken@redhat.com> 3.4.3-3
- Point linker in the right direction using %%{_lib} to fix x86_64 build issues

* Tue Sep 06 2005 Luke Macken <lmacken@redhat.com> 3.4.3-2
- Enable x11 support

* Sun Jul 10 2005 Luke Macken <lmacken@redhat.com> 3.4.3-1
- Initial package for Fedora Extras
